gmshEnt: Utility to make .geo (gmsh) format

Description Usage Arguments Details Value Examples

View source: R/gmshEnt.R

Description

Utility to make .geo (gmsh) format

Usage

1
gmshEnt(ent = "p", id = 1, ele = 2)

Arguments

ent

Character representing gmsh entities. Possible options are: "p" = Points "l" = Line "ll" = Line Loop "ps" = "Plane Surface", "Pp" = Physical Point "Pl" = Physical Line "Ps" = Physical Surface "Pv" = Physical Volume

id

Identification number.

ele

elements of each entity.

Details

See dfn2geo code for an example on how to write the output of this function to a file. See http://gmsh.info/doc/texinfo/gmsh.html#Geometry-commands

Value

A character vector. See examples.

Examples

1
2
gmshEnt(en="p", id = 1:2, ele=3:4)
gmshEnt(en="l", id = 1:2, ele=cbind(1:2, 10:11))

mathphysmx/gmshR documentation built on May 7, 2019, 1:25 p.m.