intervaLims: Vector conversion to m x 2 matrix of interval limits

Description Usage Arguments Details Value Examples

View source: R/intervaLims.R

Description

Vector conversion to m x 2 matrix of interval limits

Usage

1

Arguments

x

Numeric vector of increasing values (x[i] < x[j], i<j) that are the limits of the partition of an interval with limits x[1] and x[n]. Where length(x)=n+1.

Details

This code was implemented having in mind a mixture of disjoint uniform distributions.

Value

A m x 2 matrix with each row giving the limits of one interval.

Examples

1
2
xe <- c(0,1, 4,6)
intervaLims(xe)

mathphysmx/gmshR documentation built on May 7, 2019, 1:25 p.m.