Description Usage Arguments Details Value Examples
Utility to make .geo (gmsh) format
1 | gmshEnt(ent = "p", id = 1, ele = 2)
|
ent |
Character representing gmsh entities. Possible options are: "p" = Points "l" = Line "ll" = Line Loop "ps" = "Plane Surface", "Pp" = Physical Point "Pl" = Physical Line "Ps" = Physical Surface "Pv" = Physical Volume |
id |
Identification number. |
ele |
elements of each entity. |
See dfn2geo code for an example on how to write the output of this function to a file. See http://gmsh.info/doc/texinfo/gmsh.html#Geometry-commands
A character vector. See examples.
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.