Description Usage Arguments Details Value Examples
Vector conversion to m x 2 matrix of interval limits
1 | intervaLims(x)
|
x |
Numeric vector of increasing values ( |
This code was implemented having in mind a mixture of disjoint uniform distributions.
A m x 2 matrix with each row giving the limits of one interval.
1 2 | xe <- c(0,1, 4,6)
intervaLims(xe)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.